'use strict';

var _templateObject;
function _taggedTemplateLiteral(strings, raw) { if (!raw) { raw = strings.slice(0); } return Object.freeze(Object.defineProperties(strings, { raw: { value: Object.freeze(raw) } })); }
var path = require('path');
var meow = require('meow');
var _package$1 = require('./package-9a9abcc4.js');
var cli = require('./cli-7e8e9944.js');
var nodemon = require('nodemon');
var concurrently = require('concurrently');
var chalk = require('chalk');
var fs = require('fs');
var _package = require('./package-a73ac254.js');
var outdent = require('outdent');
var pkgUtils = require('@sanity/pkg-utils');
function _interopDefaultCompat(e) {
  return e && typeof e === 'object' && 'default' in e ? e : {
    default: e
  };
}
var path__default = /*#__PURE__*/_interopDefaultCompat(path);
var meow__default = /*#__PURE__*/_interopDefaultCompat(meow);
var nodemon__default = /*#__PURE__*/_interopDefaultCompat(nodemon);
var concurrently__default = /*#__PURE__*/_interopDefaultCompat(concurrently);
var chalk__default = /*#__PURE__*/_interopDefaultCompat(chalk);
var fs__default = /*#__PURE__*/_interopDefaultCompat(fs);
var outdent__default = /*#__PURE__*/_interopDefaultCompat(outdent);
async function linkWatch(_ref) {
  var _ref2;
  let {
    basePath
  } = _ref;
  var _a;
  const packageJson = JSON.parse(fs__default.default.readFileSync(path__default.default.join(basePath, "package.json"), "utf8"));
  const packageConfig = await pkgUtils.loadConfig({
    cwd: basePath
  });
  const outDir = (_ref2 = packageConfig == null ? void 0 : packageConfig.dist) !== null && _ref2 !== void 0 ? _ref2 : cli.defaultOutDir;
  const watch = {
    command: "npm run watch",
    extensions: "ts,js,png,svg,gif,jpeg,css",
    ...((_a = packageJson.sanityPlugin) == null ? void 0 : _a.linkWatch)
  };
  nodemon__default.default({
    watch: [outDir],
    ext: watch.extensions,
    exec: "yalc push --changed"
    //delay: 1000
  });

  const folder = path__default.default.join(basePath, outDir);
  if (!(await _package.fileExists(folder))) {
    await _package.mkdir(folder);
  }
  const pkg = await _package.getPackage({
    basePath,
    validate: false
  });
  concurrently__default.default([watch.command]);
  nodemon__default.default.on("start", function () {
    cli.log.info(outdent__default.default(_templateObject || (_templateObject = _taggedTemplateLiteral(["\n        Watching ", " for changes to files with extensions: ", "\n\n        To test this package in Sanity Studio or another package, in a separate shell run:\n        cd /path/to/sanity/studio-or-package\n\n        Then, run one of the below commands, based on the package manager used in studio-or-package:\n\n        ## yarn\n        ", "\n\n        ## npm\n        ", "\n      "])), outDir, watch.extensions, chalk__default.default.greenBright("yalc add --link ".concat(pkg.name, " && yarn install")), chalk__default.default.greenBright("npx yalc add ".concat(pkg.name, " && npx yalc link ").concat(pkg.name, " && npm install"))).trimStart());
  }).on("quit", function () {
    process.exit();
  }).on("restart", function (files) {
    cli.log.info("Found changes in files:", chalk__default.default.magentaBright(files));
    cli.log.info("Pushing new yalc package...");
  });
}
const description = "Run the watch command and pushes any changes to yalc";
const help = "\nUsage\n  $ ".concat(_package$1.pkg.binname, " link-watch [<args>]\n\nOptions\n  --silent      Do not print info and warning messages\n  --verbose     Log everything. This option conflicts with --silent\n  --version     Output the version number\n  --help        Output usage information\n\nConfiguration\nTo override the default watch command configuration, provide an override in package.json under sanityPlugin:\n{\n  \"sanityPlugin\": {\n    \"watchCommand\": \"microbundle watch --format modern,esm,cjs --jsx React.createElement --jsxImportSource react --css inline\",\n    \"linkWatch\": {\n      \"command\": \"npm run watch\",\n      \"extensions\": \"js,png,svg,gif,jpeg,css\"\n    }\n  }\n}\n\nExamples\n  # Run the watch command and pushes any changes to yalc\n  $ ").concat(_package$1.pkg.binname, " link-watch\n");
const flags = {
  ...cli.sharedFlags,
  watch: {
    type: "boolean",
    default: false
  }
};
function run(_ref3) {
  let {
    argv
  } = _ref3;
  const cli = meow__default.default(help, {
    flags,
    argv,
    description
  });
  const basePath = path__default.default.resolve(cli.input[0] || process.cwd());
  return linkWatch({
    basePath
  });
}
exports.default = run;
//# sourceMappingURL=link-watch-aff484af.js.map
